```{include} ../README.md
:start-line: 0
:end-line: 5
```

_Curate, store, track, query, integrate, and learn from biological data._

```{warning}
Public beta: Currently only recommended for collaborators as we still make breaking changes.
```

- Get started with the [guide](guide/index).
- Explore the [API reference](api) and [FAQ](faq/index).
- See the [source code](https://github.com/laminlabs/lamindb) on GitHub.

```{toctree}
:maxdepth: 1
:hidden:

guide/index
api
faq/index
changelog
```
